Difference

Struct Difference 

pub struct Difference<'a, T, S, A = Global>
where A: Allocator,
{ /* private fields */ }
A lazy iterator producing elements in the difference of HashSets.

This struct is created by the difference method on HashSet. See its documentation for more.