Drain

Struct Drain 

pub struct Drain<'a, K, A = Global>
where A: Allocator,
{ /* private fields */ }
A draining iterator over the items of a HashSet.

This struct is created by the drain method on HashSet. See its documentation for more.