Intersection

Struct Intersection 

pub struct Intersection<'a, T, S, A = Global>
where A: Allocator,
{ /* private fields */ }
A lazy iterator producing elements in the intersection of HashSets.

This struct is created by the intersection method on HashSet. See its documentation for more.