#[non_exhaustive]pub struct ItemStatic {
pub attributes: Vec<Attribute>,
pub visibility: Visibility,
pub static_token: Static,
pub name: Ident,
pub init: Option<ItemStaticInit>,
/* private fields */
}Expand description
A static declaration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attributes: Vec<Attribute>The inner attributes that are applied to the static declaration.
visibility: VisibilityThe visibility of the static.
static_token: StaticThe static keyword.
name: IdentThe name of the static.
init: Option<ItemStaticInit>The initializer, if the static has one.
A static without an initializer has to be assigned before it can be read, either by a script or by the caller through the storage the virtual machine has been configured with.
Implementations
Sourceimpl ItemStatic
impl ItemStatic
Sourcepub fn parse_with_meta(
parser: &mut Parser<'_>,
attributes: Vec<Attribute>,
visibility: Visibility,
static_token: Static,
) -> Result<Self, Error>
pub fn parse_with_meta( parser: &mut Parser<'_>, attributes: Vec<Attribute>, visibility: Visibility, static_token: Static, ) -> Result<Self, Error>
Parse #ident and attach the given meta