#[non_exhaustive]pub struct StmtSemi {
pub expr: Expr,
pub semi_token: SemiColon,
}Expand description
A semi-terminated expression.
These have special meaning since they indicate that whatever block or function they belong to should not evaluate to the value of the expression if it is the last expression in the block.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.expr: ExprThe expression that is considered to be semi-terminated.
semi_token: SemiColonThe semi-token associated with the expression.