pub fn replace(budget: usize) -> BudgetGuardExpand description
Replace the current budget returning a guard that will restore the one which was in effect when it is dropped.
pub fn replace(budget: usize) -> BudgetGuardReplace the current budget returning a guard that will restore the one which was in effect when it is dropped.