pub struct SourceId { /* private fields */ }Expand description
The opaque identifier of a source file, as returned by
Sources::insert.
It can be used to reference the inserted source file in the future through
methods such as Sources::get.
Implementations