pub struct Unit<S = DefaultStorage> { /* private fields */ }Expand description
Instructions and debug info from a single compilation.
See rune::prepare for more.
Implementations
Sourceimpl Unit
impl Unit
Sourcepub fn emit_instructions<O>(
&self,
out: &mut O,
sources: &Sources,
without_source: bool,
) -> Result<()>where
O: WriteColor,
Available on crate feature emit only.
pub fn emit_instructions<O>(
&self,
out: &mut O,
sources: &Sources,
without_source: bool,
) -> Result<()>where
O: WriteColor,
emit only.Dump instructions in a human readable manner.
Sourceimpl<S> Unit<S>
impl<S> Unit<S>
Sourcepub fn from_parts(data: Logic<S>, debug: Option<DebugInfo>) -> Result<Self>
pub fn from_parts(data: Logic<S>, debug: Option<DebugInfo>) -> Result<Self>
Constructs a new unit from a pair of data and debug info.
Sourcepub fn debug_info(&self) -> Option<&DebugInfo>
pub fn debug_info(&self) -> Option<&DebugInfo>
Access debug information for the given location if it is available.
Sourcepub fn globals_len(&self) -> usize
pub fn globals_len(&self) -> usize
The number of static slots declared in this unit.
This is the size that a Globals storage constructed for this unit
will have.
Sourcepub fn global_slot(&self, hash: &Hash) -> Option<usize>
pub fn global_slot(&self, hash: &Hash) -> Option<usize>
Lookup the slot assigned to the static item with the given type hash.
This is how a caller addresses a static by item without having to know its slot.