ToTypeHash

Trait ToTypeHash 

pub trait ToTypeHash { }
Helper trait used to convert a type into a type hash.

This is used by Hash::type_hash to get the type hash of an object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors