pub struct IntoIter<K, V, A = Global>where
A: Allocator,{ /* private fields */ }Expand description
An owning iterator over the entries of a HashMap in arbitrary order.
The iterator element type is (K, V).
This struct is created by the into_iter method on HashMap
(provided by the IntoIterator trait). See its documentation for more.
The map cannot be used after calling that method.
Examples
use rune::alloc::HashMap;
let map: HashMap<_, _> = [(1, "a"), (2, "b"), (3, "c")].try_into()?;
let mut iter = map.into_iter();
let mut vec = vec![iter.next(), iter.next(), iter.next()];
// The `IntoIter` iterator produces items in arbitrary order, so the
// items must be sorted to test them against a sorted array.
vec.sort_unstable();
assert_eq!(vec, [Some((1, "a")), Some((2, "b")), Some((3, "c"))]);
// It is fused iterator
assert_eq!(iter.next(), None);
assert_eq!(iter.next(), None);