pub struct Union<'a, T, S, A = Global>where A: Allocator,{ /* private fields */ }
A lazy iterator producing elements in the union of HashSets.
HashSet
This struct is created by the union method on HashSet. See its documentation for more.
struct
union