Struct rune::runtime::VmError

source ·
pub struct VmError { /* private fields */ }
Errors raised by the execution of the virtual machine.

Implementations

source

impl VmError

source

pub fn emit<O>(&self, out: &mut O, sources: &Sources) -> Result<(), EmitError>where O: WriteColor,

Available on crate feature emit only.

Generate formatted diagnostics capable of referencing source lines and hints.

See prepare for how to use.

source

impl VmError

source

pub fn panic<D>(message: D) -> Selfwhere D: BoxedPanic,

Return an error encapsulating a panic.

source

pub fn bad_argument<T>(arg: usize, value: &Value) -> Result<Self, VmError>where T: TypeOf,

Bad argument.

source

pub fn expected<T>(actual: TypeInfo) -> Selfwhere T: TypeOf,

Construct an expected error.

source

pub fn expected_any(actual: TypeInfo) -> Self

Construct an expected any error.

source

pub fn kind(&self) -> &VmErrorKind

Access the underlying error kind.

source

pub fn into_kind(self) -> VmErrorKind

Access the underlying error kind while consuming the error.

source

pub fn as_unwound( &self ) -> (&VmErrorKind, Option<(&Arc<Unit>, usize, &[CallFrame])>)

Unpack an unwinded error, if it is present.

source

pub fn into_unwound(self) -> (Self, Option<(Arc<Unit>, usize, Vec<CallFrame>)>)

Unpack an unwinded error, if it is present.